@@ -12,6 +12,12 @@ class ProductAttributeValuesMapper(Mapper):
         raw = {}
         i = 0
 
+        try:
+            if type(list(array.values())[0]) == str:
+                array = {'0': array}
+        except:
+            pass
+
         for item in array.values():
             i += 1
             raw.update({str(i): {
@@ -24,6 +30,9 @@ class ProductAttributeValuesMapper(Mapper):
                     'attributeGroupId': item.get('attributeGroupId'),
                     'cssClass': item.get('cssClass'),
 
+                    'attributeId': item.get('attributeId'),
+                    'productId': item.get('productId'),
+
                     'attributeValues': {
                         'id': item.get('id'),
                         'value': item.get('value'),
@@ -37,6 +46,10 @@ class ProductAttributeValuesMapper(Mapper):
         result = []
 
         for item in raw.values():
-            result.append(mapper.createObject(item.get(list(item)[0])))
+
+            if i == 1:
+                result = mapper.createObject(item.get(list(item)[0]))
+            else:
+                result.append(mapper.createObject(item.get(list(item)[0])))
 
         return result
